<?php
$labels = array();
$labels['shownotifies'] = 'Desktop Notifications';
$labels['onlynew'] = 'Show only new messages';
$labels['conf_browser'] = 'Configure browser';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Notification\'s excluded directories';
$labels['check_ok'] = 'Your browser settings are correct.';
$labels['check_fail'] = 'It was not possible to show a notification, please click "Configure browser"!';
$labels['check_fail_blocked'] = 'Your browser blocked the notification, please set the permission in the browser settings!';
$labels['no_notifications'] = 'Your browser does not support Desktop Notifications!';
$labels['ok_notifications'] = 'The website already got the permission. Desktop Notifications should work.';
$labels['notification_title'] = 'New E-Mail from [from]';

$labels['seconds'] = 'seconds';
$labels['off'] = 'off';
$labels['durable'] = 'durable';

$labels['no_mailbox'] = 'don\'t show mailbox';
$labels['short_mailbox'] = 'show short mailbox';
$labels['full_mailbox'] = 'show full mailbox';

$labels['notifier_popuptype'] = 'How to open message on notification click';
$labels['new_tab'] = 'In a new tab';
$labels['new_window'] = 'In a new window';
?>
