<?php
$labels = array();
$labels['shownotifies'] = 'Desktop Benachrichtigungen';
$labels['onlynew'] = 'Nur neue Nachrichten anzeigen';
$labels['conf_browser'] = 'Browser einrichten';
$labels['test_browser'] = 'Testen';
$labels['excluded_directories'] = 'Von Benachrichtigung ausgeschlossene Ordner';
$labels['check_ok'] = 'Ihre Browsereinstellungen sind korrekt.';
$labels['check_fail'] = 'Es konnte keine Benachrichtigung angezeigt werden, bitte klicken Sie auf "Browser einrichten"!';
$labels['check_fail_blocked'] = 'Ihr Browser hat die Benachrichtigung blockert, bitte erlauben Sie diese in den Einstellungen Ihres Browsers!';
$labels['no_notifications'] = 'Ihr Browser unterst�tzt noch keine Desktop Benachrichtigungen!';
$labels['ok_notifications'] = 'Die Website hat die Erlaubnis bereits erhalten. Desktop Benachrichtgungen sollten funktionieren.';
$labels['notification_title'] = 'Neue E-Mail von [from]';

$labels['seconds'] = 'Sekunden';
$labels['off'] = 'Aus';
$labels['durable'] = 'dauerhaft';

$labels['no_mailbox'] = 'Ordnernamen nicht anzeigen';
$labels['short_mailbox'] = 'kurzen Ordnernamen anzeigen';
$labels['full_mailbox'] = 'ganzen Ordnernamen anzeigen';

$labels['notifier_popuptype'] = 'Nachrichten nach Klick auf Benachrichtigung öffnen';
$labels['new_tab'] = 'In einem neuen Tab';
$labels['new_window'] = 'In einem neuen Fenster';
?>
