<?php
$labels = array();
$labels['shownotifies'] = 'Notifiche Desktop';
$labels['conf_browser'] = 'Configura browser';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Lista cartelle escluse dalle notifiche';
$labels['check_ok'] = 'Le impostazioni del tuo browser sono corrette!';
$labels['check_fail'] = 'Impossibile mostrare le notifiche: e\' necessario cliccare su \'Configura browser\'!';
$labels['check_fail_blocked'] = 'Il tuo browser sta bloccando le notifiche: e\' necessario abilitarle dalla configurazione del browser!';
$labels['no_notifications'] = 'Il tuo browser non supporta le Notifiche Desktop!';
$labels['ok_notifications'] = 'Permission impostate correttamente. Le Notifiche Desktop dovrebbero funzionare correttamente';
$labels['notification_title'] = 'Nuova e-mail da [from]';

$labels['seconds'] = 'secondi';
$labels['off'] = 'disattivate';
$labels['durable'] = 'lunghe';

$labels['no_mailbox'] = 'non mostrare cartelle';
$labels['short_mailbox'] = 'mostra cartelle brevi';
$labels['full_mailbox'] = 'mostra cartelle complete';
?>
