<?php
$labels = array();
$labels['shownotifies'] = 'Upozornenia na pracovnej ploche';
$labels['onlynew'] = 'Iba nové správy';
$labels['conf_browser'] = 'Nakonfigurovať prehliadač';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Vylúčené adresára oznámenia';
$labels['check_ok'] = 'Nastavenia tvojho prehliadača sú správne.';
$labels['check_fail'] = 'Nebolo možné zobraziť upozornenie, kliknite na "Nakonfigurovať prehliadač"!';
$labels['check_fail_blocked'] = 'Tvoj prehliadač blokoval upozornenie, prosím, nastav právomoci v prehliadači!';
$labels['no_notifications'] = 'Tvoj prehliadač nepodporuje upozornenia na pracovnej ploche!';
$labels['ok_notifications'] = 'Stránka má už povolené upozornenia. Upozornenia na pracovnej ploche by mali fungovať.';
$labels['notification_title'] = 'Nový E-Mail od [from]';

$labels['seconds'] = 'sekúnd';
$labels['off'] = 'vypnuté';
$labels['durable'] = 'permanentne';

$labels['no_mailbox'] = 'nezobrazovať priečinok pošty';
$labels['short_mailbox'] = 'zobraziť skrátený priečinok pošty';
$labels['full_mailbox'] = 'zobraziť plnohodnotný priečinok pošty';
?>
