<?php
$labels = array();
$labels['shownotifies'] = 'Notifications de bureau';
$labels['onlynew'] = 'Notification seulement dès messages nouveaux';
$labels['conf_browser'] = 'Configurer votre navigateur';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Répertoires exclus des notifications';
$labels['check_ok'] = 'Les paramètres de votre navigateur sont corrects.';
$labels['check_fail'] = 'Il n\'était pas possible d\'afficher les notifications, s\'il vous plaît cliquez sur "Configurer votre navigateur"!';
$labels['check_fail_blocked'] = 'Votre navigateur a bloqué la notification, s\'il vous plaît autorisez-les dans les paramètres du navigateur!';
$labels['no_notifications'] = 'Votre navigateur ne supporte pas les notifications de bureau!';
$labels['ok_notifications'] = 'Le site web a déjà obtenu les permissions. La notification de bureau devrait fonctionner.';
$labels['notification_title'] = 'Nouvel E-Mail de [from]';

$labels['seconds'] = 'secondes';
$labels['off'] = 'désactivées';
$labels['durable'] = 'permanentes';

$labels['no_mailbox'] = 'ne pas montrer le message';
$labels['short_mailbox'] = 'montrer un aperçu du message';
$labels['full_mailbox'] = 'montrer tout le message';
?>
