<?php
$labels = array();
$labels['shownotifies'] = 'Oznámení na ploše';
$labels['onlynew'] = 'Zobrazit pouze nové zprávy';
$labels['conf_browser'] = 'Nastavit prohlížeč';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Neoznamovat nové zprávy ve složkách';
$labels['check_ok'] = 'Nastavení prohlížeče je v pořádku.';
$labels['check_fail'] = 'Nebylo možné zobrazit upozornění, klikněte prosím na "Nastavit prohlížeč"!';
$labels['check_fail_blocked'] = 'Váš prohlížeč blokuje oznámení na ploše, prosím, nastavte oprávnění pro stránku v prohlížeči!';
$labels['no_notifications'] = 'Váš prohlížeč nepodporuje oznámení na ploše!';
$labels['ok_notifications'] = 'Stránka má potřebná oprávnění. Oznámení na ploše by mělo fungovat.';
$labels['notification_title'] = 'Nový mail od [from]';

$labels['seconds'] = 'vteřin';
$labels['off'] = 'vypnuté';
$labels['durable'] = 'trvale';

$labels['no_mailbox'] = 'nezobrazovat složky';
$labels['short_mailbox'] = 'zobrazit zkrácené názvy složek';
$labels['full_mailbox'] = 'zobrazit dlouhé názvy složek';

$labels['notifier_popuptype'] = 'Jak otevřít zprávu při kliknutí na oznámení';
$labels['new_tab'] = 'V nové záložce';
$labels['new_window'] = 'V novém okně';
?>
