<?php
$labels = array();
$labels['shownotifies'] = 'Сповіщення на робочому столі';
$labels['onlynew'] = 'Показувати лише нові повідомлення';
$labels['conf_browser'] = 'Налаштування браузера';
$labels['test_browser'] = 'Перевірка';
$labels['excluded_directories'] = 'Вилучити каталоги для сповіщень';
$labels['check_ok'] = 'Ваш браузер налаштований правильно.';
$labels['check_fail'] = 'Неможливо відобразити сповіщення, будь ласка, натисніть кнопку "Налаштування браузера"!';
$labels['check_fail_blocked'] = 'Ваш браузер заблокував сповіщення, будь ласка, надайте дозвіл у налаштуваннях браузера!';
$labels['no_notifications'] = 'Ваш браузер не підтримує сповіщення на робочому столі!';
$labels['ok_notifications'] = 'Сайт вже отримав дозвіл. Сповіщення повинні відображатися.';
$labels['notification_title'] = 'Новий E-Mail від [from]';

$labels['seconds'] = 'секунд';
$labels['off'] = 'вимк.';
$labels['durable'] = 'постійно';

$labels['no_mailbox'] = 'не показувати поштову скриньку';
$labels['short_mailbox'] = 'показати коротку інформацію про поштову скриньку';
$labels['full_mailbox'] = 'показати повну інформацію про поштову скриньку';

$labels['notifier_popuptype'] = 'Як відкрити повідомлення при натисканні на сповіщення?';
$labels['new_tab'] = 'В новій вкладці';
$labels['new_window'] = 'В новому вікні';
?>
