<?php
$labels = array();
$labels['shownotifies'] = 'Bureaubladmeldingen';
$labels['onlynew'] = 'Alleen voor nieuwe berichten';
$labels['conf_browser'] = 'Configureer browser';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Geen meldingen tonen voor volgende mappen';
$labels['check_ok'] = 'Uw browserinstellingen zijn correct.';
$labels['check_fail'] = 'Kon geen melding tonen, klik op "Configureer browser"!';
$labels['check_fail_blocked'] = 'Uw browser heeft de melding geblokkeerd. U moet meldingen van deze website toestaan in uw browserinstellingen!';
$labels['no_notifications'] = 'Uw browser ondersteunt geen bureaubladmeldingen!';
$labels['ok_notifications'] = 'Deze website is reeds toegestaan. Bureaubladmeldingen zouden moeten werken.';
$labels['notification_title'] = 'Nieuwe e-mail van [from]';

$labels['seconds'] = 'seconden';
$labels['off'] = 'uit';
$labels['durable'] = 'permanent';

$labels['no_mailbox'] = 'mapnaam niet tonen';
$labels['short_mailbox'] = 'toon korte mapnaam';
$labels['full_mailbox'] = 'toon volledige mapnaam';
?>
