<?php
$labels = [];
$labels['shownotifies'] = '桌面通知';
$labels['onlynew'] = '只在新邮件时弹出';
$labels['conf_browser'] = '启用桌面通知';
$labels['test_browser'] = '测试';
$labels['excluded_directories'] = '收到新邮件时不通知的文件夹';
$labels['check_ok'] = '您的浏览器设置正确.';
$labels['check_fail'] = '无法弹出通知，请点击“启用桌面通知!';
$labels['check_fail_blocked'] = '您的浏览器阻止了桌面通知，请修改浏览器设置';
$labels['no_notifications'] = '您的浏览器不支持桌面通知!';
$labels['ok_notifications'] = '桌面通知已经在正常运行.';
$labels['notification_title'] = '来自 [from] 的新邮件';

$labels['seconds'] = '秒';
$labels['off'] = 'off';
$labels['durable'] = '不消失';

$labels['no_mailbox'] = '不显示邮件';
$labels['short_mailbox'] = '显示缩略邮件';
$labels['full_mailbox'] = '显示邮件全文';

$labels['notifier_popuptype'] = '点击新通知时的打开方式';
$labels['new_tab'] = '在新标签页打开';
$labels['new_window'] = '在新窗口打开';
?>
