<?php
$labels = array();
$labels['shownotifies'] = 'デスクトップ通知';
$labels['onlynew'] = '新しいメッセージだけを表示する';
$labels['conf_browser'] = 'ブラウザの設定';
$labels['test_browser'] = 'テスト';
$labels['excluded_directories'] = '通知から除外するディレクトリ';
$labels['check_ok'] = 'あなたのブラウザは正しく設定されています。';
$labels['check_fail'] = '通知を表示する事が出来ませんでした。"ブラウザの設定" をクリックして下さい。';
$labels['check_fail_blocked'] = 'あなたのブラウザは通知をブロックしています。ブラウザの設定で許可してください。';
$labels['no_notifications'] = 'あなたのブラウザではデスクトップ通知が利用出来ません。';
$labels['ok_notifications'] = 'このWebサイトはすでに許可されています。デスクトップ通知は有効です。';
$labels['notification_title'] = '新着メール from [from]';

$labels['seconds'] = '秒間';
$labels['off'] = '無効';
$labels['durable'] = '消えない';

$labels['no_mailbox'] = 'メールボックス名を表示しない';
$labels['short_mailbox'] = '短いメールボックス名で表示する';
$labels['full_mailbox'] = '全てのメールボックス名を表示する';
?>
