<?php
$labels = array();
$labels['shownotifies'] = 'Уведомления на рабочем столе';
$labels['onlynew'] = 'Показывать только новые сообщения';
$labels['conf_browser'] = 'Настройка браузера';
$labels['test_browser'] = 'Проверка';
$labels['excluded_directories'] = 'Исключить каталоги для уведомлений';
$labels['check_ok'] = 'Ваш браузер настроен верно.';
$labels['check_fail'] = 'Невозможно сделать вывод уведомлений, пожалуйста, нажмите кнопку "Настройка браузера"!';
$labels['check_fail_blocked'] = 'Ваш браузер заблокировал уведомления, пожалуйста, установите разрешение в настройках браузера!';
$labels['no_notifications'] = 'Ваш браузер не поддерживает вывод уведомлений на рабочий стол!';
$labels['ok_notifications'] = 'Сайт уже получил разрешение. Уведомления должны работать.';
$labels['notification_title'] = 'Новый E-Mail от [from]';

$labels['seconds'] = 'секунд';
$labels['off'] = 'выкл.';
$labels['durable'] = 'постоянно';

$labels['no_mailbox'] = 'не показывать почтовый ящик';
$labels['short_mailbox'] = 'показать короткую информацию о почтовом ящике';
$labels['full_mailbox'] = 'показать полную информацию о почтовом ящике';

$labels['notifier_popuptype'] = 'Как открыть сообщение при нажатии на уведомление';
$labels['new_tab'] = 'В новой вкладке';
$labels['new_window'] = 'В новом окне';
?>
