<?php
//Thanks to David Perez www.closemarketing.es
$labels = array();
$labels['shownotifies'] = 'Notificaciones Escritorio';
$labels['onlynew'] = 'Mostrar sólo los mensajes nuevos';
$labels['conf_browser'] = 'Configurar Navegador';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Directorios notificaciones Excluidos';
$labels['check_ok'] = 'La configuración de tu Navegador es correcta.';
$labels['check_fail'] = 'No fue posible mostrar la notificación, por favor haz clic en "Configurar Navegador"!';
$labels['check_fail_blocked'] = 'Your browser blocked the notification, please set the permission in the browser settings!';
$labels['no_notifications'] = 'Su Navegador no permite nofitificaciones!';
$labels['ok_notifications'] = 'Esta web ya tiene permiso. Las notificaciones por Escritorio deberían de estar funcionando.';
$labels['notification_title'] = 'Nuevo Email de [from]';

$labels['seconds'] = 'segundos';
$labels['off'] = 'desactivado';
$labels['durable'] = 'durable';

$labels['no_mailbox'] = 'no mostrar bandeja';
$labels['short_mailbox'] = 'mostrar un extracto de bandeja';
$labels['full_mailbox'] = 'mostrar toda la bandeja';
?>
