<?php
$labels = array();
$labels['shownotifies'] = 'Powiadomienia Pulpitu';
$labels['onlynew'] = 'Pokazuj tylko nowe wiadomości';
$labels['conf_browser'] = 'Konfiguracja&nbsp;przeglądarki';
$labels['test_browser'] = 'Test';
$labels['excluded_directories'] = 'Foldery wykluczone z powiadomień';
$labels['check_ok'] = 'Ustawienia Twojej przeglądarki są prawidłowe.';
$labels['check_fail'] = 'Wyświetlenie powiadomienia nie było możliwe. Proszę użyj opcji "Konfiguracja&nbsp;przeglądarki"!';
$labels['check_fail_blocked'] = 'Twoja przeglądarka zablokowała powiadomienie. Proszę ustaw uprawnienia w ustawieniach przeglądarki.';
$labels['no_notifications'] = 'Twoja przeglądarka nie obsługuje powiadomień pulpitu!';
$labels['ok_notifications'] = 'Ta strona posiada już wymagane uprawnienia. Powiadomienia pulpitu powinny działać prawidłowo.';
$labels['notification_title'] = 'Nowy e-mail od [from]';

$labels['seconds'] = 'sekund(y)';
$labels['off'] = 'wyłączone';
$labels['durable'] = 'ciągłe';

$labels['no_mailbox'] = 'nie pokazuj nazwy folderu';
$labels['short_mailbox'] = 'pokazuj krótką nazwę folderu';
$labels['full_mailbox'] = 'pokazuj pełną ścieżkę folderu';

$labels['notifier_popuptype'] = 'Jak otwierać wiadomości po kliknięciu w powiadomienie';
$labels['new_tab'] = 'W nowej zakładce';
$labels['new_window'] = 'W nowym oknie' ;
