<?php
$labels = array();
$labels['shownotifies'] = 'Notificação no Desktop';
$labels['onlynew'] = 'Mostrar somente novas mensagens';
$labels['conf_browser'] = 'Configurar o navegador';
$labels['test_browser'] = 'Teste';
$labels['excluded_directories'] = 'Notificações de pastas excluídas';
$labels['check_ok'] = 'Suas configurações do navegador estão corretas.';
$labels['check_fail'] = 'Não foi possível mostrar a notificação, assim clique em "Configurar navegador"!';
$labels['check_fail_blocked'] = 'Seu navegador bloqueou a notificação, assim configure a permissão nas configurações do navegador!';
$labels['no_notifications'] = 'Seu navegador não suporta Notificações no Desktop!';
$labels['ok_notifications'] = 'A página já tem a permissão. A Notificação de Desktop deve funcionar.';
$labels['notification_title'] = 'Novo e-mail de [from]';

$labels['seconds'] = 'segundos';
$labels['off'] = 'desativado';
$labels['durable'] = 'duração';

$labels['no_mailbox'] = 'Não mostrar caixa de entrada';
$labels['short_mailbox'] = 'mostrar caixa de entrada curta';
$labels['full_mailbox'] = 'mostrar caixa de entrada toda';

$labels['notifier_popuptype'] = 'Como abrir mensagens com clique na notificação';
$labels['new_tab'] = 'Em uma nova aba';
$labels['new_window'] = 'Em uma nova janela';
?>
